
# --------------------------------------------------------------------------
#
# Script name: wNAm sample code
#
# Purpose of script: Filter records from full wNAm database
#
# Script author: Nick McKay
#
# Date created: 2020-08-25
#
# Email: nick@nau.edu
#
# Citation: Routson et al. (2020)  A Multiproxy Database of Western North American Holocene Paleoclimate Records is available for download from http://lipdverse.org/wNAm/current_version/
#
# code offered as-is. For questions or feedback on LiPD-utilities code, please contact Nick <nick@nau.edu>, or post an issue on github at https://github.com/nickmckay/lipd-utilities
# --------------------------------------------------------------------------

# --------------------------------------------------------------------------

#install the lipdR package from github
#remotes::install_github("nickmckay/lipd-utilities",subdir = "R")

library(lipdR)

#load the database
load("wNAm0_15_0.RData")

## look at individual records
TSids <-  lipdR::pullTsVariable(sTS,"paleoData_TSid")
                               
# filter chosen record from full record list
findRecordName <- which(TSids == 'WEB31e807ae')
recordTS <- TS[findRecordName];

# extract site names
siteNames =  lipdR::pullTsVariable(sTS,"geo_siteName")

# filter datasets containing the desired site name from the full record list
findSite = which(grepl('Lake',siteNames))
selectedSiteTS = TS[findSite]

# view site names
sort(unique(siteNames[findSite]))

## Filtering of the database by variable name and units

# starting with the entire database, filter for records that
# have temperature or precipitation records and
# have units in °C or mm
  
variableName = pullTsVariable(TS,"paleoData_variableName")
units =  pullTsVariable(TS,"paleoData_units")


# create filters for records with calibrated temperature or precipitation data
wNAm_temp = which(grepl(x = variableName , pattern = 'temperature',ignore.case = T) & 
                  grepl(x = units , pattern = 'degC',ignore.case = T))

wNAm_precip = which(grepl(x = variableName , pattern = 'precipitation',ignore.case = T) & 
                    grepl(x = units , pattern = 'mm',ignore.case = T))

ind = c(wNAm_temp, wNAm_precip)

TempPrecipTS = TS[ind]; # filter the full timeseries for all selected records.

length(TempPrecipTS) # See how many records are in this filtered subset of the database

## Filtering of the database by climate interpretations

#view all climate interpretations
climInterpretation = pullTsVariable(TS,"interpretation1_variable")
                               
# check names
unique(climInterpretation)

#create filters for records with hydroclimate interpretations
wNAm_p = which('P' == climInterpretation)
wNAm_pe = which('P-E' == climInterpretation)

com = c(wNAm_p,wNAm_pe) #creating a single index of precipitation and P-E records

hydroTS = TS[com]; #creating a subset database of only hydroclimate records
                               
#create filters for records with temperature interpretations
wNAm_t =  which('T' == climInterpretation)

tempTS = TS[wNAm_t]


#further filtering temperature records by season and proxy
sg <- pullTsVariable(TS,"interpretation1_seasonalityGeneral")
mb = which('annual' == sg) #index all annual records
mc = which('summerOnly' == sg) #index all SummerOnly records
me = which('winterOnly' == sg) #index all WinterOnly records
                               
mf = c(mb, mc, me) #index of annual, summer and winter
                     

pg <- pullTsVariable(TS,"paleoData_proxyGeneral")

pollen = which(pg == "pollen") #find all pollen records

mg = intersect(mf,com); #intersect seasons wanted with temperature records

mx = intersect(mg,pollen); #intersecting season, variable with proxy

subTS = TS[mx]; #creating a subset database

length(subTS) #counting the number of filtered records 
                               