% --------------------------------------------------------------------------
%
% Script name: wNAm sample code
%
% Purpose of script: Filter records from full wNAm database
%
% Script author: Cody Routson (translated from Dr. Nick McKay's code)
%
% Date created: 2020-08-25
%
% Email: cody.routson@nau.edu
%
% Citation: Routson et al. (2020)  A Multiproxy Database of Western North American Holocene Paleoclimate Records is available for download from http://lipdverse.org/wNAm/current_version/
%
% code offered as-is. For questions or feedback on LiPD-utilities code, please contact Nick <nick@nau.edu>, or post an issue on github at https://github.com/nickmckay/lipd-utilities
% --------------------------------------------------------------------------

% --------------------------------------------------------------------------
close all
clear

%load the database
load wNAm0_15_0.mat

%define a function for cell arrays
uniqueCell = @(X) unique(X(find(cellfun(@ischar,X))));


%% look at individual records

TSids = {TS.paleoData_TSid}';

% filter chosen record from full record list
findRecordName = find(strcmp(TSids,'WEB31e807ae'));
recordTS = TS(findRecordName);

% extract dataset names
siteNames = {TS.geo_siteName}';

% filter datasets containing the desired site name(s) from the full record
% list. Here we screen for site names that include 'lake'
findSite = find(~cellfun(@isempty,strfind(lower(siteNames),'lake')));
selectedSiteTS = TS(findSite);

% view site names
sort(unique(siteNames(findSite)))

%% Filtering of the database by variable name and units

% starting with the entire database, filter for records that
% have temperature or precipitation records and
% have units in C or mm
  
variableName = {TS.paleoData_variableName}';
units = {TS.paleoData_units}';

% create filters for records with calibrated temperature or precipitaiton data
wNAm_temp = find(strcmp(variableName , 'temperature') & strcmp(units , 'degC'))';
wNAm_precip = find(strcmp(variableName , 'precipitation') & strcmp(units , 'mm'))';
ind = [wNAm_temp, wNAm_precip];

TempPrecipTS = TS(ind); % filter the full timeseries for all selected records.

length(TempPrecipTS) % See how many records are in this filtered subset of the database

%% Filtering of the database by climate interpretations

%view all climate interpretations
climInterpretation = {TS.interpretation1_variable}';

% check names
uniqueCell(climInterpretation)

%create filters for records with hydroclimate interpretations
wNAm_p = find(strcmpi('P',{TS.interpretation1_variable}'));
wNAm_pe = find(strcmpi('P-E',{TS.interpretation1_variable}'));
c = [wNAm_p;wNAm_pe]; %creating a single index of precipitation and P-E records

hydroTS = TS(c); %creating a subset database of only hydroclimate records

%create filters for records with temperature interpretations
wNAm_t = find(strcmpi('T',{TS.interpretation1_variable}'));

tempTS = TS(wNAm_t);


%further filtering temperature records by season and proxy

mb = find(strncmp('annual',{TS.interpretation1_seasonalityGeneral}',7)); %index all annual records
mc = find(strncmp('summerOnly',{TS.interpretation1_seasonalityGeneral}',7)); %index all SummerOnly records
me = find(strncmp('winterOnly',{TS.interpretation1_seasonalityGeneral}',7)); %index all WinterOnly records

mf = [mb; mc; me]; %index of annual, summer and winter

pollen = find(arrayfun(@(x)strcmp(x.paleoData_proxyGeneral,'pollen'),TS)); %find all pollen records

mg = intersect(mf,c); %intersect seasons wanted with temperature records

mx = intersect(mg,pollen); %intersecting season, variable with proxy

subTS = TS(mx); %creating a subset database

length(subTS) %counting the number of filtered records 
